@@ -29,7 +29,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #include "gdb-buddy.h"
 
